/*********************************************************************
 *   _      _        _     _                             _           *
 *  | |__  (_) _ __ | | __| |  ___  _ __    _ __    ___ | |_         *
 *  | '_ \ | || '__|| |/ /| | / _ \| '__|  | '_ \  / _ \| __|        *
 *  | |_) || || |   |   < | ||  __/| |   _ | | | ||  __/| |_         *
 *  |_.__/ |_||_|   |_|\_\|_| \___||_|  (_)|_| |_| \___| \__|        *
 *                                                                   *
 *********************************************************************
 * Copyright 2002                                                    *
 * Jrgen Birkler (birkler@yahoo.com)                                *
 *********************************************************************/

#ifndef __DISPLAY_H__
#define __DISPLAY_H__

/**
 * @file
 * LCD Display Driver Interface
 * printf_P.
 * @ingroup ATMEL_AVR_Embedded_Display
 * @author Jrgen Birkler (birkler@yahoo.com) 
 */

/** @page ATMEL_AVR_Embedded_Display_AsciiControlCharacters
 *
 * - Carrige return <b>\\r</b> - Return cursor to beginning of line.
 * - New Line <b>\\n</b> Advance cursor to next line at same column.
 * - Backspace <b>\\b</b> Move cursor one step left if not beginning of line.
 * - Vertical tab <b>\\v</b> Set cursor at home position (top left).
 * - Form Feed <b>\\f</b> Clear display and set cursor at home position (top left).
 */


/**
 * @defgroup ATMEL_AVR_Embedded_Display LCD Display Driver
 * Display driver that implement a char out that is compatible
 * with printf_p and understands specific acsii control characters
 *
 * @ingroup ATMEL_AVR_Embedded
 *
 * Uses I2C to interface to a philips LCD display driver. See
 * for more info.
 *
 *
 * @copydoc ATMEL_AVR_Embedded_Display_AsciiControlCharacters
 *
 */

/** 
 * \addtogroup ATMEL_AVR_Embedded_Display
 * \@{
 */



/**
 * Output a character to the LCD display
 * @param ch Character to output
 *
 * The driver understand certain acsii control characaters.
 * @copydoc ATMEL_AVR_Embedded_Display_AsciiControlCharacters
 */
void Display_OutChar(char ch);



void Display_On(void);

void Display_Off(void);

void Display_Init(void);


/**\@}*/

#endif //__DISPLAY_H__
