/*********************************************************************
 *   _      _        _     _                             _           *
 *  | |__  (_) _ __ | | __| |  ___  _ __    _ __    ___ | |_         *
 *  | '_ \ | || '__|| |/ /| | / _ \| '__|  | '_ \  / _ \| __|        *
 *  | |_) || || |   |   < | ||  __/| |   _ | | | ||  __/| |_         *
 *  |_.__/ |_||_|   |_|\_\|_| \___||_|  (_)|_| |_| \___| \__|        *
 *                                                                   *
 *********************************************************************
 * Copyright 2002                                                    *
 * Jrgen Birkler (birkler@yahoo.com)                                *
 *********************************************************************/

/**
 * @file
 * Buzzer Utilities library
 * @ingroup ATMEL_AVR_Embedded_BuzzerUtilities
 * @author Jrgen Birkler (birkler@yahoo.com) 
 */
                                                                  
#include "buzzer.h"
#include <inttypes.h>
#include "hardware.h"
#include <avr/io.h>

//static volatile const char* playString_p = NULL;

#define TIMER1_ENABLE_OUTPUT_COMPARE_B_INTERRUPT() {sbi(TIMSK,OCIE1B);}
#define TIMER1_DISABLE_OUTPUT_COMPARE_B_INTERRUPT() {cbi(TIMSK,OCIE1B);}
#define TIMER1_SET_OUTPUT_COMPARE_B(_value)  OCR1B = (_value)
#define TIMER1_SET_PIN_TOGGLE_ON_OUTPUT_COMPARE_B()  {cbi(TCCR1A,COM1B1);sbi(TCCR1A,COM1B0);}
#define TIMER1_SET_PIN_DISCONNECTED_OUTPUT_COMPARE_B()  {cbi(TCCR1A,COM1B1);cbi(TCCR1A,COM1B0);}
#define TIMER1_READ_COUNTER()   inw(TCNT1)

#define TIMER1_OUTPUT_COMPARE_B_OUTPUT() {sbi(DDRD,DDD4);cbi(PORTD,PD4);}
#define TIMER1_OUTPUT_COMPARE_B_OFF()   

static uint16_t length = 0;

#define buzzer_period 2000

INTERRUPT(SIG_OUTPUT_COMPARE1B)
{
  if (length > 0)
  {
    uint16_t cnt = TIMER1_READ_COUNTER();
    cnt+=buzzer_period;
    TIMER1_SET_OUTPUT_COMPARE_B(cnt);
    length--;
  }
  else {
    TIMER1_DISABLE_OUTPUT_COMPARE_B_INTERRUPT();
    TIMER1_SET_PIN_DISCONNECTED_OUTPUT_COMPARE_B();
  }
}


void Buzzer_Buzz(void)
{
  length = 200;
  TIMER1_OUTPUT_COMPARE_B_OUTPUT();
  TIMER1_SET_PIN_TOGGLE_ON_OUTPUT_COMPARE_B();
  TIMER1_ENABLE_OUTPUT_COMPARE_B_INTERRUPT();
}



inline bool Buzzer_PowerSaveOk(void)
{
  return (length==0);
}

