/*********************************************************************
 *   _      _        _     _                             _           *
 *  | |__  (_) _ __ | | __| |  ___  _ __    _ __    ___ | |_         *
 *  | '_ \ | || '__|| |/ /| | / _ \| '__|  | '_ \  / _ \| __|        *
 *  | |_) || || |   |   < | ||  __/| |   _ | | | ||  __/| |_         *
 *  |_.__/ |_||_|   |_|\_\|_| \___||_|  (_)|_| |_| \___| \__|        *
 *                                                                   *
 *********************************************************************
 * Copyright 2002                                                    *
 * Jrgen Birkler (birkler@yahoo.com)                                *
 *********************************************************************/

/**
 * @file
 * FIR Filter Implementation
 * @ingroup ATMEL_AVR_Embedded_FIRFilter
 * @author Jrgen Birkler (birkler@yahoo.com) 
 */
                                                                  


#include "fir_filter.h"
//#include "debug.h"

void FIR_Filter_Init(FIR_Filter_t* filter_p,const FIR_FilterSize_t log2size)
{
	FIR_FilterSize_t i = 1;
	i <<= log2size;
	filter_p->size = i;
	filter_p->mask = (FIR_FilterSize_t)(i-1);
	filter_p->pos = 0;
	filter_p->accumulatedSum = 0;
	
//  DEBUG_DECIMAL_(filter_p->mask);
	for (i=0; i <= filter_p->mask; i++)
	{
		filter_p->samples[i] = 0;
	}
}


FIR_FilterSample_t FIR_Filter_BoxCar_Input(FIR_Filter_t* filter_p,const FIR_FilterSample_t sample)
{
	//Boxcar is a filter where all cooeffcients are 1.
	//Also known as a sliding average
	filter_p->accumulatedSum -= filter_p->samples[filter_p->pos];
	filter_p->samples[filter_p->pos] = sample;
	filter_p->accumulatedSum += filter_p->samples[filter_p->pos];
	filter_p->pos++;
	filter_p->pos &= filter_p->mask;
  filter_p->sum = (FIR_FilterSample_t)(filter_p->accumulatedSum / filter_p->size);
  return filter_p->sum;
}

FIR_FilterSample_t FIR_Filter_GetNormalizedSum(const FIR_Filter_t* const filter_p)
{
  /*
	FIR_FilterAcculatedSum_t sum = filter_p->accumulatedSum;
	sum /= filter_p->size;
	return (FIR_FilterSample_t)(sum); */

  return filter_p->sum;
}


