//**********************************
//* Real Time Clock
//**********************************
//* Author: Jrgen Birkler
//* (C) 2000
//**********************************

#include "rtc.h"
#include "hardware.h"
#include "debug.h"
#include "date.h"

static Time_t RTC_Time = {
	RTC_COMPILE_YEAR,
	RTC_COMPILE_MONTH,
	RTC_COMPILE_DAY,
	((RTC_COMPILE_HOUR + (RTC_COMPILE_TZ/100) + 24) % 24),
	((RTC_COMPILE_MIN + (RTC_COMPILE_TZ%100) + 60) % 60),
	RTC_COMPILE_SEC,
	0
};

const Time_t* RTC_Get(void)
{
  return &RTC_Time;
}

void RTC_Set(const Time_t* const Time_p)
{
  RTC_Time=*Time_p;
}

 
void RTC_Init(void)
{
  /*
  RTC_Time.year = RTC_COMPILE_YEAR;
  RTC_Time.month = RTC_COMPILE_MONTH;
  RTC_Time.day = RTC_COMPILE_DAY;
  RTC_Time.hour = RTC_COMPILE_HOUR;
  RTC_Time.minute = RTC_COMPILE_MIN;
  RTC_Time.seconds = RTC_COMPILE_SEC;
  */
}

void RTC_Increase(uint16_t milliseconds)
{
  RTC_Time.milliseconds+=milliseconds;
  while (RTC_Time.milliseconds>=1000)
  {
    RTC_Time.milliseconds-=1000;
    RTC_Time.seconds++;
    if (RTC_Time.seconds>=60)
    {
      RTC_Time.seconds = 0;
      RTC_Time.minute++;
      if (RTC_Time.minute>=60)
      {
        RTC_Time.minute = 0;
        RTC_Time.hour++;
        if (RTC_Time.hour>23)
        {
          RTC_Time.hour=0;
          RTC_Time.day++;
          if (RTC_Time.day > DAYS_IN_MONTH(RTC_Time.month,RTC_Time.year))
          {
            RTC_Time.day = 1;
            RTC_Time.month++;
            if (RTC_Time.month > 12)
            {
              RTC_Time.month = 1;
              RTC_Time.year++;              
            }
          }
        }
      }
    }  
  }    
}

