/*********************************************************************
 *   _      _        _     _                             _           *
 *  | |__  (_) _ __ | | __| |  ___  _ __    _ __    ___ | |_         *
 *  | '_ \ | || '__|| |/ /| | / _ \| '__|  | '_ \  / _ \| __|        *
 *  | |_) || || |   |   < | ||  __/| |   _ | | | ||  __/| |_         *
 *  |_.__/ |_||_|   |_|\_\|_| \___||_|  (_)|_| |_| \___| \__|        *
 *                                                                   *
 *********************************************************************
 * Copyright 2002                                                    *
 * Jrgen Birkler (birkler@yahoo.com)                                *
 *********************************************************************/

/**
 * @file
 * Real Time Clock
 * @ingroup ATMEL_AVR_Embedded_RTC
 * @author Jrgen Birkler (birkler@yahoo.com) 
 */
                                                                  

/**
 * @defgroup ATMEL_AVR_Embedded_RTC Real Time Clock
 *
 * Real time clock driven by overflow interrupt from TIMER2
 * 
 * @ingroup ATMEL_AVR_Embedded
 * 
 */

/** 
 * \addtogroup ATMEL_AVR_Embedded_RTC
 * \@{
 */

#ifndef __RTC_H__
#define __RTC_H__

#include <inttypes.h>


///RTC time
typedef struct 
{
  uint16_t year;  ///<year
  uint8_t month;  ///<month
  uint8_t day;    ///<day
  uint8_t hour;///<hour
  uint8_t minute;///<minute
  uint8_t seconds;///<second
  uint16_t milliseconds;///<millisecond
} Time_t;


///Days in february given the year
#define DAYS_IN_FEBRUARY(year)    ( (year & 0x0003) ? 28 : 29)

///Days in month other than february
#define DAYS_IN_OTHER(month)      ( (((month)<=6 && (month)&0x01) || ((month)>=7 && !((month)&0x01))) ? 31 : 30)

///Days in a month given month and year
#define DAYS_IN_MONTH(month,year) ( ((month)==2) ? DAYS_IN_FEBRUARY(year) : DAYS_IN_OTHER(month))


///Called at reset
void RTC_Init(void);

///Get current time
const Time_t* RTC_Get(void);

///Set new time
void RTC_Set(const Time_t* const Time_p);

/**
 * Increase current time with milliseconds
 * Called by the TIMER2 overflow interrupt.
 */
void RTC_Increase(uint16_t milliseconds);

/**@}*/

#endif //__RTC_H__
